==> mx-remastercc_19.4.tar.xz: mx-remastercc-19.4/translations/mx-remastercc_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>mxremastercc</name>
    <message>
        <location filename="../mxremastercc.ui" line="14"/>
        <source>MX Remastercc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="64"/>
        <source>Persistence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;This tool allows you to rework an ISO while running Live. &lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Remaster&lt;/span&gt; allows you to change files, applications and settings with the goal of producing a new master copy for storage or distribution. &lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Persistence&lt;/span&gt; allows you to retain data, settings and installed programs when the machine gets switched off for personal use.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="133"/>
        <source>Display help </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="136"/>
        <source>Help</source>
        <translation>Помощ</translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="143"/>
        <source>Alt+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="175"/>
        <source>About this application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="178"/>
        <source>About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="185"/>
        <source>Alt+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="217"/>
        <source>Quit application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="220"/>
        <source>Close</source>
        <translation>Затваряне</translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="227"/>
        <source>Alt+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="264"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Basic operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="274"/>
        <source>Remaster</source>
        <translation>Ремастър</translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="300"/>
        <source>Save root persistence</source>
        <translation>Съхранете рут постоянство</translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="313"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Optional operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.ui" line="323"/>
        <source>Configure live persistence</source>
        <translation>Настройте лайф постоянство</translation>
    </message>
    <message>
        <location filename="../mxremastercc.cpp" line="51"/>
        <location filename="../mxremastercc.cpp" line="100"/>
        <source>MX Remaster Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.cpp" line="99"/>
        <source>About MX Remaster Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.cpp" line="100"/>
        <source>Version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.cpp" line="101"/>
        <source>This program provides access to different remaster and persistence tools in MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.cpp" line="103"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.cpp" line="104"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.cpp" line="105"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxremastercc.cpp" line="106"/>
        <source>Cancel</source>
        <translation>Отмяна</translation>
    </message>
    <message>
        <location filename="../mxremastercc.cpp" line="122"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-remastercc_19.9.tar.xz: mx-remastercc-19.9/translations/mx-remastercc_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Remastercc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>Persistence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;This tool allows you to rework an ISO while running Live. &lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Remaster&lt;/span&gt; allows you to change files, applications and settings with the goal of producing a new master copy for storage or distribution. &lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Persistence&lt;/span&gt; allows you to retain data, settings and installed programs when the machine gets switched off for personal use.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>Display help </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Help</source>
        <translation type="unfinished">Помощ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Alt+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>About this application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Alt+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Quit application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>Close</source>
        <translation type="unfinished">Затваряне</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Alt+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Basic operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Remaster</source>
        <translation type="unfinished">Ремастър</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Save root persistence</source>
        <translation type="unfinished">Съхранете рут постоянство</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Optional operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Configure live persistence</source>
        <translation type="unfinished">Настройте лайф постоянство</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="54"/>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>MX Remaster Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>About MX Remaster Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>Version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="98"/>
        <source>This program provides access to different remaster and persistence tools in MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="102"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Cancel</source>
        <translation type="unfinished">Отмяна</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="119"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mxremastercc</name>
    <message>
        <source>Help</source>
        <translation type="vanished">Помощ</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Затваряне</translation>
    </message>
    <message>
        <source>Remaster</source>
        <translation type="vanished">Ремастър</translation>
    </message>
    <message>
        <source>Save root persistence</source>
        <translation type="vanished">Съхранете рут постоянство</translation>
    </message>
    <message>
        <source>Configure live persistence</source>
        <translation type="vanished">Настройте лайф постоянство</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Отмяна</translation>
    </message>
</context>
</TS>
